macro_rules! missing_data {
($($msg:tt)*) => { ... };
}Expand description
Helper to generate Error::MissingData.
Works very much like an anyhow!/eyre! macro, but intended for the case when trying to
extract some data from the query.
macro_rules! missing_data {
($($msg:tt)*) => { ... };
}Helper to generate Error::MissingData.
Works very much like an anyhow!/eyre! macro, but intended for the case when trying to
extract some data from the query.